@@ -6,6 +6,6 @@
 # @Software: PyCharm
 
 from __future__ import absolute_import
-from tpypi import *
+from tpypi.oh import *
 
 name = "Oh Pig"
\ No newline at end of file
